@@ -1,23 +1,21 @@
 import shlex
 import subprocess
-from pathlib import Path
 
 from .console import console
 from .utils import extract_csv_column
 
 
-def cluster(sample, ratio, distance, quality, threads, **kwargs):
-    pipeline = Path(kwargs["pipelinedir"])
+def cluster(sample, pipeline, ratio, distance, quality, threads, verbose):
 
-    extracted_csv = pipeline / f"{sample}.barcodes.q{quality}.tsv"
+    extracted_csv = pipeline / f"{sample}.q{quality}.barcodes.tsv"
 
-    if not extracted_csv.with_suffix(".c2.tsv").is_file():
-        input_file = extract_csv_column(extracted_csv, 2)
-
-    output_file = pipeline / f"{sample}.barcodes.q{quality}.r{ratio}d{distance}.tsv"
+    output_file = pipeline / f"{sample}.q{quality}.barcodes.r{ratio}d{distance}.tsv"
 
     if not output_file.is_file():
-        console.log(f"[green]{sample}[/green]: clustering barcodes")
+        if not extracted_csv.with_suffix(".c2.tsv").is_file():
+            input_file = extract_csv_column(extracted_csv, 2)
+
+        console.print(f"[green]{sample}[/green]: clustering barcodes")
         command = f"starcode -d {distance} -r {ratio} -t {threads} -i {input_file} -o {output_file}"
 
         args = shlex.split(command)
@@ -28,7 +26,7 @@ def cluster(sample, ratio, distance, quality, threads, **kwargs):
             stderr=subprocess.STDOUT,
             universal_newlines=True,
         )
-        if kwargs["verbose"]:
+        if verbose:
             console.print("[yellow]STARCODE OUTPUT:")
             console.print(
                 "\n".join(
@@ -39,8 +37,9 @@ def cluster(sample, ratio, distance, quality, threads, **kwargs):
                     ]
                 )
             )
+        input_file.unlink()
 
-        console.log(f"[green]{sample}[/green]: clustering complete")
+        console.print(f"[green]{sample}[/green]: clustering complete")
 
     else:
-        console.log(f"[green]{sample}[/green]: skipping clustering")
+        console.print(f"[green]{sample}[/green]: skipping clustering")
